@@ -6,8 +6,8 @@ from urllib.parse import unquote as url_unquote
 from urllib.parse import unquote_plus
 
 import attr
-import pip_shims.shims
 from orderedmultidict import omdict
+from pip_shims import shims
 from urllib3.util import parse_url as urllib3_parse
 from urllib3.util.url import Url
 
@@ -18,7 +18,7 @@ from .utils import extras_to_string, parse_extras
 if MYPY_RUNNING:
     from typing import Dict, Optional, Text, Tuple, TypeVar, Union
 
-    from pip_shims.shims import Link
+    from shims import Link
 
     _T = TypeVar("_T")
     STRING_TYPE = Union[bytes, str, Text]
@@ -29,7 +29,7 @@ def _get_parsed_url(url):
     # type: (S) -> Url
     """This is a stand-in function for `urllib3.util.parse_url`
 
-    The orignal function doesn't handle special characters very well, this simply splits
+    The original function doesn't handle special characters very well, this simply splits
     out the authentication section, creates the parsed url, then puts the authentication
     section back in, bypassing validation.
 
@@ -139,7 +139,7 @@ class URI(object):
             if key == "egg":
                 from .utils import parse_extras
 
-                name, stripped_extras = pip_shims.shims._strip_extras(val)
+                name, stripped_extras = shims._strip_extras(val)
                 if stripped_extras:
                     extras = tuple(parse_extras(stripped_extras))
             elif key == "subdirectory":
@@ -370,7 +370,7 @@ class URI(object):
     @property
     def as_link(self):
         # type: () -> Link
-        link = pip_shims.shims.Link(
+        link = shims.Link(
             self.to_string(escape_password=False, strip_ssh=False, direct=False)
         )
         return link
@@ -480,16 +480,14 @@ def update_url_name_and_fragment(name_with_extras, ref, parsed_dict):
     if name_with_extras:
         fragment = ""  # type: Optional[str]
         parsed_extras = ()
-        name, extras = pip_shims.shims._strip_extras(name_with_extras)
+        name, extras = shims._strip_extras(name_with_extras)
         if extras:
             parsed_extras = parsed_extras + tuple(parse_extras(extras))
         if parsed_dict["fragment"] is not None:
             fragment = "{0}".format(parsed_dict["fragment"])
             if fragment.startswith("egg="):
                 _, _, fragment_part = fragment.partition("=")
-                fragment_name, fragment_extras = pip_shims.shims._strip_extras(
-                    fragment_part
-                )
+                fragment_name, fragment_extras = shims._strip_extras(fragment_part)
                 name = name if name else fragment_name
                 if fragment_extras:
                     parsed_extras = parsed_extras + tuple(parse_extras(fragment_extras))
