@@ -287,7 +287,7 @@ def _get_parsed_url(url):
     # type: (S) -> Url
     """This is a stand-in function for `urllib3.util.parse_url`
 
-    The orignal function doesn't handle special characters very well, this simply splits
+    The original function doesn't handle special characters very well, this simply splits
     out the authentication section, creates the parsed url, then puts the authentication
     section back in, bypassing validation.
 
@@ -567,7 +567,10 @@ def split_ref_from_uri(uri):
     path = parsed.path if parsed.path else ""
     scheme = parsed.scheme if parsed.scheme else ""
     ref = None
-    if scheme != "file" and "@" in path:
+    schema_is_filelike = scheme in ("", "file")
+    if (not schema_is_filelike and "@" in path) or (
+        schema_is_filelike and (re.match("^.*@[^/@]*$", path) or path.count("@") >= 2)
+    ):
         path, _, ref = path.rpartition("@")
     parsed = parsed._replace(path=path)
     return (parsed.url, ref)
